[−][src]Function libblkid_rs::encode_string
pub fn encode_string(string: &str) -> Result<String>
Encode potentially unsafe characters in the given string parameter.
pub fn encode_string(string: &str) -> Result<String>
Encode potentially unsafe characters in the given string parameter.