[−][src]Function libblkid_rs::parse_tag_string
pub fn parse_tag_string(tag_string: &str) -> Result<(String, String)>
Parse a tag string into a tuple of type and value
pub fn parse_tag_string(tag_string: &str) -> Result<(String, String)>
Parse a tag string into a tuple of type and value