BlkidPartition

Struct BlkidPartition 

pub struct BlkidPartition<'a>(/* private fields */);
A handle for working with a probed partition.

Implementations

Source

impl<'a> BlkidPartition<'a>

pub fn get_table(&self) -> Result<BlkidParttable<'a>>

Get the partition table for the given partition.

pub fn get_name(&self) -> Result<Option<String>>

Get the partition name or None if it can’t be represented.

pub fn get_uuid(&self) -> Result<Option<Uuid>>

Get the partition UUID or None if the partition table doesn’t support it.

pub fn get_partno(&self) -> Result<c_uint>

Get the partition number.

pub fn get_start(&self) -> BlkidSectors

Get the start of the partition in units of sectors.

pub fn get_size(&self) -> BlkidSectors

Get the size of the partition in units of sectors.

pub fn get_type(&self) -> c_int

Get the numeric partition type. Use get_type_string for the String representation.

pub fn get_type_string(&self) -> Result<String>

Get the string representation of the partition type.

pub fn get_flags(&self) -> c_ulonglong

Get the flags for the given partition.

This method is not typed as the documentation does not specify which constants are used as flags.

pub fn is_logical(&self) -> bool

Check whether the given partition is logical.

pub fn is_extended(&self) -> bool

Check whether the given partition is an extended partition.

pub fn is_primary(&self) -> bool

Check whether the given partition is a primary partition.