pub struct BlkidParttable<'a>(/* private fields */);Expand description
A handle for working with partition tables.
Implementations
Sourceimpl<'a> BlkidParttable<'a>
impl<'a> BlkidParttable<'a>
Sourcepub fn get_id(&self) -> Result<String>
pub fn get_id(&self) -> Result<String>
Get the ID of the partition table. Given that this could be a UUID or some
other form of identifier, the return value is a String to cover all cases.
Sourcepub fn get_offset(&self) -> Result<BlkidBytes>
pub fn get_offset(&self) -> Result<BlkidBytes>
Get the offset of the partition table in bytes.
Sourcepub fn get_parent(&self) -> Option<BlkidPartition<'a>>
pub fn get_parent(&self) -> Option<BlkidPartition<'a>>
Get the parent partition in the case of nested partition tables.