[−][src]Struct libblkid_rs::BlkidDev
Block device found by blkid
Implementations
impl BlkidDev[src]
pub fn devname(&self) -> Result<&str>[src]
Get the device name for a blkid device
pub fn devsize(&self) -> Result<BlkidSize>[src]
Get the size of a device as reported by the cache
pub fn tag_iter(&self) -> BlkidTagIterⓘImportant traits for BlkidTagIter
impl Iterator for BlkidTagIter type Item = (String, String);[src]
Important traits for BlkidTagIter
impl Iterator for BlkidTagIter type Item = (String, String);Iterate through tags in associated with the given block device
pub fn has_tag(&self, type_: &str, value: &str) -> Result<bool>[src]
Return true if the given device has a specified tag