[][src]Struct libblkid_rs::BlkidPartlist

pub struct BlkidPartlist(_);

A handle for traversing a list of partitions.

Implementations

impl BlkidPartlist[src]

pub fn number_of_partitions(&mut self) -> Result<c_int>[src]

Get the number of partitions in the list.

pub fn get_table(&mut self) -> Result<BlkidParttable>[src]

Get the partition table for a list of partitions.

pub fn get_partition(&mut self, index: c_int) -> Result<BlkidPartition>[src]

Get a partition at the given index of the list.

pub fn get_partition_by_partno(&mut self, num: c_int) -> Result<BlkidPartition>[src]

Get a partition by the number listed in the partition table. Correctly handles "out-of-order" partition tables.

pub fn get_partition_by_devno(
    &mut self,
    dev: &BlkidDevno
) -> Result<BlkidPartition>
[src]

Get a partition using the device number of a partition.