[][src]Struct libblkid_rs::BlkidParttable

pub struct BlkidParttable(_);

A handle for working with partition tables.

Implementations

impl BlkidParttable[src]

pub fn get_type(&self) -> Result<String>[src]

Get the type of the partition table.

pub fn get_id(&self) -> Result<String>[src]

Get the ID of the partition table. Given that this could be a UUID or some other form of identifier, the return value is a String to cover all cases.

pub fn get_offset(&self) -> Result<BlkidBytes>[src]

Get the offset of the partition table in bytes.

pub fn get_parent(&self) -> Option<BlkidPartition>[src]

Get the parent partition in the case of nested partition tables.